@@ -6,4 +6,4 @@ from roblopy.assets import Assets
 from roblopy.assets import Asset
 from roblopy.groups import Groups
 from roblopy.groups import Group
-from .utils.errors import BadStatus, NotFound, BadRequest
\ No newline at end of file
+from .utils.errors import BadStatus, NotFound, BadRequest, ErrorMessage
